[evolution-data-server/wip/mcrha/libical-glib] [addressbook] Address some issues reported by .gir



commit c75abc1ffc18ab4f204bfaab5b2ee58d2b02fe36
Author: Milan Crha <mcrha redhat com>
Date:   Thu Apr 25 17:46:26 2019 +0200

    [addressbook] Address some issues reported by .gir

 .../backends/carddav/e-book-backend-carddav.c      |  4 +-
 .../backends/file/e-book-backend-file.c            | 23 +++---
 .../backends/google/e-book-backend-google.c        |  4 +-
 .../backends/ldap/e-book-backend-ldap.c            | 29 ++++---
 .../libedata-book/e-book-backend-sqlitedb.c        | 14 ++--
 .../libedata-book/e-book-backend-sync.c            | 16 ++--
 src/addressbook/libedata-book/e-book-backend.c     | 92 +++++++++++-----------
 src/addressbook/libedata-book/e-book-backend.h     | 73 ++++++++---------
 src/addressbook/libedata-book/e-book-cache.c       | 21 ++++-
 src/addressbook/libedata-book/e-book-cache.h       |  2 +
 .../libedata-book/e-book-meta-backend.c            | 20 ++---
 src/addressbook/libedata-book/e-book-sqlite.c      | 14 ++--
 tests/libedata-book/test-book-meta-backend.c       | 12 +--
 13 files changed, 172 insertions(+), 152 deletions(-)
---
diff --git a/src/addressbook/backends/carddav/e-book-backend-carddav.c 
b/src/addressbook/backends/carddav/e-book-backend-carddav.c
index e0ba6b5f8..3509229ea 100644
--- a/src/addressbook/backends/carddav/e-book-backend-carddav.c
+++ b/src/addressbook/backends/carddav/e-book-backend-carddav.c
@@ -1298,7 +1298,7 @@ ebb_carddav_get_backend_property (EBookBackend *book_backend,
        }
 
        /* Chain up to parent's method. */
-       return E_BOOK_BACKEND_CLASS (e_book_backend_carddav_parent_class)->get_backend_property 
(book_backend, prop_name);
+       return E_BOOK_BACKEND_CLASS (e_book_backend_carddav_parent_class)->impl_get_backend_property 
(book_backend, prop_name);
 }
 
 static gchar *
@@ -1381,7 +1381,7 @@ e_book_backend_carddav_class_init (EBookBackendCardDAVClass *klass)
        book_meta_backend_class->get_ssl_error_details = ebb_carddav_get_ssl_error_details;
 
        book_backend_class = E_BOOK_BACKEND_CLASS (klass);
-       book_backend_class->get_backend_property = ebb_carddav_get_backend_property;
+       book_backend_class->impl_get_backend_property = ebb_carddav_get_backend_property;
 
        object_class = G_OBJECT_CLASS (klass);
        object_class->constructed = e_book_backend_carddav_constructed;
diff --git a/src/addressbook/backends/file/e-book-backend-file.c 
b/src/addressbook/backends/file/e-book-backend-file.c
index 0a44e900a..a70e2c237 100644
--- a/src/addressbook/backends/file/e-book-backend-file.c
+++ b/src/addressbook/backends/file/e-book-backend-file.c
@@ -1125,9 +1125,8 @@ book_backend_file_get_backend_property (EBookBackend *backend,
                return prop_value;
        }
 
-       /* Chain up to parent's get_backend_property() method. */
-       return E_BOOK_BACKEND_CLASS (e_book_backend_file_parent_class)->
-               get_backend_property (backend, prop_name);
+       /* Chain up to parent's method. */
+       return E_BOOK_BACKEND_CLASS (e_book_backend_file_parent_class)->impl_get_backend_property (backend, 
prop_name);
 }
 
 static gboolean
@@ -2139,15 +2138,15 @@ e_book_backend_file_class_init (EBookBackendFileClass *class)
        backend_sync_class->get_contact_list_uids_sync = book_backend_file_get_contact_list_uids_sync;
 
        backend_class = E_BOOK_BACKEND_CLASS (class);
-       backend_class->get_backend_property = book_backend_file_get_backend_property;
-       backend_class->start_view = book_backend_file_start_view;
-       backend_class->stop_view = book_backend_file_stop_view;
-       backend_class->get_direct_book = book_backend_file_get_direct_book;
-       backend_class->configure_direct = book_backend_file_configure_direct;
-       backend_class->set_locale = book_backend_file_set_locale;
-       backend_class->dup_locale = book_backend_file_dup_locale;
-       backend_class->create_cursor = book_backend_file_create_cursor;
-       backend_class->delete_cursor = book_backend_file_delete_cursor;
+       backend_class->impl_get_backend_property = book_backend_file_get_backend_property;
+       backend_class->impl_start_view = book_backend_file_start_view;
+       backend_class->impl_stop_view = book_backend_file_stop_view;
+       backend_class->impl_get_direct_book = book_backend_file_get_direct_book;
+       backend_class->impl_configure_direct = book_backend_file_configure_direct;
+       backend_class->impl_set_locale = book_backend_file_set_locale;
+       backend_class->impl_dup_locale = book_backend_file_dup_locale;
+       backend_class->impl_create_cursor = book_backend_file_create_cursor;
+       backend_class->impl_delete_cursor = book_backend_file_delete_cursor;
 }
 
 static void
diff --git a/src/addressbook/backends/google/e-book-backend-google.c 
b/src/addressbook/backends/google/e-book-backend-google.c
index 0008303c2..071bc028d 100644
--- a/src/addressbook/backends/google/e-book-backend-google.c
+++ b/src/addressbook/backends/google/e-book-backend-google.c
@@ -1274,7 +1274,7 @@ ebb_google_get_backend_property (EBookBackend *book_backend,
        }
 
        /* Chain up to parent's method. */
-       return E_BOOK_BACKEND_CLASS (e_book_backend_google_parent_class)->get_backend_property (book_backend, 
prop_name);
+       return E_BOOK_BACKEND_CLASS (e_book_backend_google_parent_class)->impl_get_backend_property 
(book_backend, prop_name);
 }
 
 static void
@@ -1362,7 +1362,7 @@ e_book_backend_google_class_init (EBookBackendGoogleClass *klass)
        book_meta_backend_class->remove_contact_sync = ebb_google_remove_contact_sync;
 
        book_backend_class = E_BOOK_BACKEND_CLASS (klass);
-       book_backend_class->get_backend_property = ebb_google_get_backend_property;
+       book_backend_class->impl_get_backend_property = ebb_google_get_backend_property;
 
        object_class = G_OBJECT_CLASS (klass);
        object_class->constructed = ebb_google_constructed;
diff --git a/src/addressbook/backends/ldap/e-book-backend-ldap.c 
b/src/addressbook/backends/ldap/e-book-backend-ldap.c
index 6168a7a07..ebcc09706 100644
--- a/src/addressbook/backends/ldap/e-book-backend-ldap.c
+++ b/src/addressbook/backends/ldap/e-book-backend-ldap.c
@@ -4919,9 +4919,8 @@ book_backend_ldap_get_backend_property (EBookBackend *backend,
 
        }
 
-       /* Chain up to parent's get_backend_property() method. */
-       return E_BOOK_BACKEND_CLASS (e_book_backend_ldap_parent_class)->
-               get_backend_property (backend, prop_name);
+       /* Chain up to parent's method. */
+       return E_BOOK_BACKEND_CLASS (e_book_backend_ldap_parent_class)->impl_get_backend_property (backend, 
prop_name);
 }
 
 static void
@@ -5916,20 +5915,20 @@ e_book_backend_ldap_class_init (EBookBackendLDAPClass *class)
        backend_class->authenticate_sync = book_backend_ldap_authenticate_sync;
 
        book_backend_class = E_BOOK_BACKEND_CLASS (class);
-       book_backend_class->get_backend_property = book_backend_ldap_get_backend_property;
-       book_backend_class->open = book_backend_ldap_open;
-       book_backend_class->create_contacts = book_backend_ldap_create_contacts;
-       book_backend_class->modify_contacts = book_backend_ldap_modify_contacts;
-       book_backend_class->remove_contacts = book_backend_ldap_remove_contacts;
-       book_backend_class->get_contact = book_backend_ldap_get_contact;
-       book_backend_class->get_contact_list = book_backend_ldap_get_contact_list;
-       book_backend_class->get_contact_list_uids = book_backend_ldap_get_contact_list_uids;
-       book_backend_class->start_view = book_backend_ldap_start_view;
-       book_backend_class->stop_view = book_backend_ldap_stop_view;
-       book_backend_class->refresh = book_backend_ldap_refresh;
+       book_backend_class->impl_get_backend_property = book_backend_ldap_get_backend_property;
+       book_backend_class->impl_open = book_backend_ldap_open;
+       book_backend_class->impl_create_contacts = book_backend_ldap_create_contacts;
+       book_backend_class->impl_modify_contacts = book_backend_ldap_modify_contacts;
+       book_backend_class->impl_remove_contacts = book_backend_ldap_remove_contacts;
+       book_backend_class->impl_get_contact = book_backend_ldap_get_contact;
+       book_backend_class->impl_get_contact_list = book_backend_ldap_get_contact_list;
+       book_backend_class->impl_get_contact_list_uids = book_backend_ldap_get_contact_list_uids;
+       book_backend_class->impl_start_view = book_backend_ldap_start_view;
+       book_backend_class->impl_stop_view = book_backend_ldap_stop_view;
+       book_backend_class->impl_refresh = book_backend_ldap_refresh;
 
        /* Register our ESource extension. */
-       E_TYPE_SOURCE_LDAP;
+       g_type_ensure (E_TYPE_SOURCE_LDAP);
 }
 
 static void
diff --git a/src/addressbook/libedata-book/e-book-backend-sqlitedb.c 
b/src/addressbook/libedata-book/e-book-backend-sqlitedb.c
index 79283d418..a8abc60de 100644
--- a/src/addressbook/libedata-book/e-book-backend-sqlitedb.c
+++ b/src/addressbook/libedata-book/e-book-backend-sqlitedb.c
@@ -6013,7 +6013,7 @@ cursor_count_position_locked (EBookBackendSqliteDB *ebsdb,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_new:
+ * e_book_backend_sqlitedb_cursor_new: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @folderid: folder id of the address-book
  * @sexp: search expression; use NULL or an empty string to get all stored contacts.
@@ -6094,7 +6094,7 @@ e_book_backend_sqlitedb_cursor_new (EBookBackendSqliteDB *ebsdb,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_free:
+ * e_book_backend_sqlitedb_cursor_free: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to free
  *
@@ -6151,7 +6151,7 @@ collect_results_for_cursor_cb (gpointer ref,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_step:
+ * e_book_backend_sqlitedb_cursor_step: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to use
  * @flags: The #EbSdbCursorStepFlags for this step
@@ -6370,7 +6370,7 @@ e_book_backend_sqlitedb_cursor_step (EBookBackendSqliteDB *ebsdb,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_set_target_alphabetic_index:
+ * e_book_backend_sqlitedb_cursor_set_target_alphabetic_index: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor to modify
  * @index: The alphabetic index
@@ -6419,7 +6419,7 @@ e_book_backend_sqlitedb_cursor_set_target_alphabetic_index (EBookBackendSqliteDB
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_set_sexp:
+ * e_book_backend_sqlitedb_cursor_set_sexp: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor
  * @sexp: The new query expression for @cursor
@@ -6465,7 +6465,7 @@ e_book_backend_sqlitedb_cursor_set_sexp (EBookBackendSqliteDB *ebsdb,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_calculate:
+ * e_book_backend_sqlitedb_cursor_calculate: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor
  * @total: (out) (allow-none): A return location to store the total result set for this cursor
@@ -6550,7 +6550,7 @@ e_book_backend_sqlitedb_cursor_calculate (EBookBackendSqliteDB *ebsdb,
 }
 
 /**
- * e_book_backend_sqlitedb_cursor_compare_contact:
+ * e_book_backend_sqlitedb_cursor_compare_contact: (skip)
  * @ebsdb: An #EBookBackendSqliteDB
  * @cursor: The #EbSdbCursor
  * @contact: The #EContact to compare
diff --git a/src/addressbook/libedata-book/e-book-backend-sync.c 
b/src/addressbook/libedata-book/e-book-backend-sync.c
index f5451b089..11b34beca 100644
--- a/src/addressbook/libedata-book/e-book-backend-sync.c
+++ b/src/addressbook/libedata-book/e-book-backend-sync.c
@@ -243,14 +243,14 @@ e_book_backend_sync_class_init (EBookBackendSyncClass *klass)
        klass->get_contact_list_uids_sync = book_backend_sync_get_contact_list_uids_sync;
 
        book_backend_class = E_BOOK_BACKEND_CLASS (klass);
-       book_backend_class->open = book_backend_sync_open;
-       book_backend_class->refresh = book_backend_sync_refresh;
-       book_backend_class->create_contacts = book_backend_sync_create_contacts;
-       book_backend_class->modify_contacts = book_backend_sync_modify_contacts;
-       book_backend_class->remove_contacts = book_backend_sync_remove_contacts;
-       book_backend_class->get_contact = book_backend_sync_get_contact;
-       book_backend_class->get_contact_list = book_backend_sync_get_contact_list;
-       book_backend_class->get_contact_list_uids = book_backend_sync_get_contact_list_uids;
+       book_backend_class->impl_open = book_backend_sync_open;
+       book_backend_class->impl_refresh = book_backend_sync_refresh;
+       book_backend_class->impl_create_contacts = book_backend_sync_create_contacts;
+       book_backend_class->impl_modify_contacts = book_backend_sync_modify_contacts;
+       book_backend_class->impl_remove_contacts = book_backend_sync_remove_contacts;
+       book_backend_class->impl_get_contact = book_backend_sync_get_contact;
+       book_backend_class->impl_get_contact_list = book_backend_sync_get_contact_list;
+       book_backend_class->impl_get_contact_list_uids = book_backend_sync_get_contact_list_uids;
 }
 
 static void
diff --git a/src/addressbook/libedata-book/e-book-backend.c b/src/addressbook/libedata-book/e-book-backend.c
index 35dbb873d..a8639c86d 100644
--- a/src/addressbook/libedata-book/e-book-backend.c
+++ b/src/addressbook/libedata-book/e-book-backend.c
@@ -713,8 +713,8 @@ e_book_backend_class_init (EBookBackendClass *class)
        backend_class->prepare_shutdown = book_backend_prepare_shutdown;
 
        class->use_serial_dispatch_queue = TRUE;
-       class->get_backend_property = book_backend_get_backend_property;
-       class->notify_update = book_backend_notify_update;
+       class->impl_get_backend_property = book_backend_get_backend_property;
+       class->impl_notify_update = book_backend_notify_update;
        class->shutdown = book_backend_shutdown;
 
        g_object_class_install_property (
@@ -1105,7 +1105,7 @@ book_backend_open_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->open != NULL);
+       g_return_if_fail (class->impl_open != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -1120,7 +1120,7 @@ book_backend_open_thread (GSimpleAsyncResult *simple,
 
                e_backend_ensure_online_state_updated (E_BACKEND (backend), cancellable);
 
-               class->open (backend, data_book, opid, cancellable);
+               class->impl_open (backend, data_book, opid, cancellable);
        }
 
        g_object_unref (data_book);
@@ -1163,7 +1163,7 @@ e_book_backend_open (EBookBackend *backend,
 
        g_simple_async_result_set_check_cancellable (simple, cancellable);
 
-       if (class->open != NULL) {
+       if (class->impl_open != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, TRUE,
                        book_backend_open_thread);
@@ -1274,7 +1274,7 @@ book_backend_refresh_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->refresh != NULL);
+       g_return_if_fail (class->impl_refresh != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -1288,7 +1288,7 @@ book_backend_refresh_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->refresh (backend, data_book, opid, cancellable);
+               class->impl_refresh (backend, data_book, opid, cancellable);
        }
 
        g_object_unref (data_book);
@@ -1331,7 +1331,7 @@ e_book_backend_refresh (EBookBackend *backend,
 
        g_simple_async_result_set_check_cancellable (simple, cancellable);
 
-       if (class->refresh != NULL) {
+       if (class->impl_refresh != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_refresh_thread);
@@ -1450,7 +1450,7 @@ book_backend_create_contacts_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->create_contacts != NULL);
+       g_return_if_fail (class->impl_create_contacts != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -1466,7 +1466,7 @@ book_backend_create_contacts_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->create_contacts (
+               class->impl_create_contacts (
                        backend, data_book, opid, cancellable, (const gchar * const *) async_context->strv, 
async_context->opflags);
        }
 
@@ -1522,7 +1522,7 @@ e_book_backend_create_contacts (EBookBackend *backend,
        g_simple_async_result_set_op_res_gpointer (
                simple, async_context, (GDestroyNotify) async_context_free);
 
-       if (class->create_contacts != NULL) {
+       if (class->impl_create_contacts != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_create_contacts_thread);
@@ -1651,7 +1651,7 @@ book_backend_modify_contacts_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->modify_contacts != NULL);
+       g_return_if_fail (class->impl_modify_contacts != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -1667,7 +1667,7 @@ book_backend_modify_contacts_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->modify_contacts (
+               class->impl_modify_contacts (
                        backend, data_book, opid, cancellable, (const gchar * const *) async_context->strv, 
async_context->opflags);
        }
 
@@ -1723,7 +1723,7 @@ e_book_backend_modify_contacts (EBookBackend *backend,
        g_simple_async_result_set_op_res_gpointer (
                simple, async_context, (GDestroyNotify) async_context_free);
 
-       if (class->modify_contacts != NULL) {
+       if (class->impl_modify_contacts != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_modify_contacts_thread);
@@ -1846,7 +1846,7 @@ book_backend_remove_contacts_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->remove_contacts != NULL);
+       g_return_if_fail (class->impl_remove_contacts != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -1862,7 +1862,7 @@ book_backend_remove_contacts_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->remove_contacts (
+               class->impl_remove_contacts (
                        backend, data_book, opid, cancellable, (const gchar * const *) async_context->strv, 
async_context->opflags);
        }
 
@@ -1918,7 +1918,7 @@ e_book_backend_remove_contacts (EBookBackend *backend,
        g_simple_async_result_set_op_res_gpointer (
                simple, async_context, (GDestroyNotify) async_context_free);
 
-       if (class->remove_contacts != NULL) {
+       if (class->impl_remove_contacts != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_remove_contacts_thread);
@@ -2040,7 +2040,7 @@ book_backend_get_contact_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->get_contact != NULL);
+       g_return_if_fail (class->impl_get_contact != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -2056,7 +2056,7 @@ book_backend_get_contact_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->get_contact (
+               class->impl_get_contact (
                        backend, data_book, opid, cancellable,
                        async_context->uid);
        }
@@ -2110,7 +2110,7 @@ e_book_backend_get_contact (EBookBackend *backend,
        g_simple_async_result_set_op_res_gpointer (
                simple, async_context, (GDestroyNotify) async_context_free);
 
-       if (class->get_contact != NULL) {
+       if (class->impl_get_contact != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_get_contact_thread);
@@ -2242,7 +2242,7 @@ book_backend_get_contact_list_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->get_contact_list != NULL);
+       g_return_if_fail (class->impl_get_contact_list != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -2258,7 +2258,7 @@ book_backend_get_contact_list_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->get_contact_list (
+               class->impl_get_contact_list (
                        backend, data_book, opid, cancellable,
                        async_context->query);
        }
@@ -2313,7 +2313,7 @@ e_book_backend_get_contact_list (EBookBackend *backend,
        g_simple_async_result_set_op_res_gpointer (
                simple, async_context, (GDestroyNotify) async_context_free);
 
-       if (class->get_contact_list != NULL) {
+       if (class->impl_get_contact_list != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_get_contact_list_thread);
@@ -2442,7 +2442,7 @@ book_backend_get_contact_list_uids_thread (GSimpleAsyncResult *simple,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->get_contact_list_uids != NULL);
+       g_return_if_fail (class->impl_get_contact_list_uids != NULL);
 
        data_book = e_book_backend_ref_data_book (backend);
        g_return_if_fail (data_book != NULL);
@@ -2458,7 +2458,7 @@ book_backend_get_contact_list_uids_thread (GSimpleAsyncResult *simple,
 
                opid = book_backend_stash_operation (backend, simple);
 
-               class->get_contact_list_uids (
+               class->impl_get_contact_list_uids (
                        backend, data_book, opid, cancellable,
                        async_context->query);
        }
@@ -2513,7 +2513,7 @@ e_book_backend_get_contact_list_uids (EBookBackend *backend,
        g_simple_async_result_set_op_res_gpointer (
                simple, async_context, (GDestroyNotify) async_context_free);
 
-       if (class->get_contact_list_uids != NULL) {
+       if (class->impl_get_contact_list_uids != NULL) {
                book_backend_push_operation (
                        backend, simple, cancellable, FALSE,
                        book_backend_get_contact_list_uids_thread);
@@ -2594,9 +2594,9 @@ e_book_backend_start_view (EBookBackend *backend,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->start_view);
+       g_return_if_fail (class->impl_start_view);
 
-       class->start_view (backend, view);
+       class->impl_start_view (backend, view);
 }
 
 /**
@@ -2617,9 +2617,9 @@ e_book_backend_stop_view (EBookBackend *backend,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->stop_view != NULL);
+       g_return_if_fail (class->impl_stop_view != NULL);
 
-       class->stop_view (backend, view);
+       class->impl_stop_view (backend, view);
 }
 
 /**
@@ -2740,9 +2740,9 @@ e_book_backend_get_backend_property (EBookBackend *backend,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_val_if_fail (class != NULL, NULL);
-       g_return_val_if_fail (class->get_backend_property != NULL, NULL);
+       g_return_val_if_fail (class->impl_get_backend_property != NULL, NULL);
 
-       return class->get_backend_property (backend, prop_name);
+       return class->impl_get_backend_property (backend, prop_name);
 }
 
 /**
@@ -2807,8 +2807,8 @@ e_book_backend_get_direct_book (EBookBackend *backend)
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_val_if_fail (class != NULL, NULL);
 
-       if (class->get_direct_book != NULL)
-               direct_book = class->get_direct_book (backend);
+       if (class->impl_get_direct_book != NULL)
+               direct_book = class->impl_get_direct_book (backend);
 
        return direct_book;
 }
@@ -2840,8 +2840,8 @@ e_book_backend_configure_direct (EBookBackend *backend,
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
 
-       if (class->configure_direct)
-               class->configure_direct (backend, config);
+       if (class->impl_configure_direct)
+               class->impl_configure_direct (backend, config);
 }
 
 /**
@@ -2874,10 +2874,10 @@ e_book_backend_set_locale (EBookBackend *backend,
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_val_if_fail (class != NULL, FALSE);
 
-       if (class->set_locale) {
+       if (class->impl_set_locale) {
                g_object_ref (backend);
 
-               success = class->set_locale (backend, locale, cancellable, error);
+               success = class->impl_set_locale (backend, locale, cancellable, error);
 
                if (success)
                        e_book_backend_notify_complete (backend);
@@ -2910,10 +2910,10 @@ e_book_backend_dup_locale (EBookBackend *backend)
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_val_if_fail (class != NULL, NULL);
 
-       if (class->dup_locale) {
+       if (class->impl_dup_locale) {
                g_object_ref (backend);
 
-               locale = class->dup_locale (backend);
+               locale = class->impl_dup_locale (backend);
 
                g_object_unref (backend);
        }
@@ -2944,9 +2944,9 @@ e_book_backend_notify_update (EBookBackend *backend,
 
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_if_fail (class != NULL);
-       g_return_if_fail (class->notify_update != NULL);
+       g_return_if_fail (class->impl_notify_update != NULL);
 
-       class->notify_update (backend, contact);
+       class->impl_notify_update (backend, contact);
 }
 
 /**
@@ -3146,10 +3146,10 @@ e_book_backend_create_cursor (EBookBackend *backend,
        class = E_BOOK_BACKEND_GET_CLASS (backend);
        g_return_val_if_fail (class != NULL, NULL);
 
-       if (class->create_cursor) {
+       if (class->impl_create_cursor) {
                g_object_ref (backend);
 
-               cursor = class->create_cursor (backend, sort_fields, sort_types, n_fields, error);
+               cursor = class->impl_create_cursor (backend, sort_fields, sort_types, n_fields, error);
 
                g_object_unref (backend);
        } else {
@@ -3192,8 +3192,8 @@ e_book_backend_delete_cursor (EBookBackend *backend,
 
        g_object_ref (backend);
 
-       if (class->delete_cursor)
-               success = class->delete_cursor (backend, cursor, error);
+       if (class->impl_delete_cursor)
+               success = class->impl_delete_cursor (backend, cursor, error);
        else
                g_warning ("Backend asked to delete a cursor, but does not support cursors");
 
diff --git a/src/addressbook/libedata-book/e-book-cache.c b/src/addressbook/libedata-book/e-book-cache.c
index 636a546ea..3b54705d7 100644
--- a/src/addressbook/libedata-book/e-book-cache.c
+++ b/src/addressbook/libedata-book/e-book-cache.c
@@ -138,10 +138,14 @@ enum {
 
 static guint signals[LAST_SIGNAL];
 
+static EBookCacheCursor *e_book_cache_cursor_fake_ref (EBookCacheCursor *cursor);
+static void e_book_cache_cursor_fake_unref (EBookCacheCursor *cursor);
+
 G_DEFINE_TYPE_WITH_CODE (EBookCache, e_book_cache, E_TYPE_CACHE,
                         G_IMPLEMENT_INTERFACE (E_TYPE_EXTENSIBLE, NULL))
 
 G_DEFINE_BOXED_TYPE (EBookCacheSearchData, e_book_cache_search_data, e_book_cache_search_data_copy, 
e_book_cache_search_data_free)
+G_DEFINE_BOXED_TYPE (EBookCacheCursor, e_book_cache_cursor, e_book_cache_cursor_fake_ref, 
e_book_cache_cursor_fake_unref)
 
 /**
  * e_book_cache_search_data_new:
@@ -3470,8 +3474,23 @@ ebc_search_internal (EBookCache *book_cache,
 }
 
 /******************************************************************
- *                    EBookCacheCursor Implementation                  *
+ *                    EBookCacheCursor Implementation             *
  ******************************************************************/
+
+static EBookCacheCursor *
+e_book_cache_cursor_fake_ref (EBookCacheCursor *cursor)
+{
+       /* Only for the introspection and the boxed type */
+       return cursor;
+}
+
+static void
+e_book_cache_cursor_fake_unref (EBookCacheCursor *cursor)
+{
+       /* Only for the introspection and the boxed type;
+          free with e_book_cache_cursor_free() instead */
+}
+
 typedef struct _CursorState CursorState;
 
 struct _CursorState {
diff --git a/src/addressbook/libedata-book/e-book-cache.h b/src/addressbook/libedata-book/e-book-cache.h
index 37d060a12..170dc6b9c 100644
--- a/src/addressbook/libedata-book/e-book-cache.h
+++ b/src/addressbook/libedata-book/e-book-cache.h
@@ -305,6 +305,8 @@ gboolean    e_book_cache_search_with_callback
                                                 GCancellable *cancellable,
                                                 GError **error);
 /* Cursor API */
+GType          e_book_cache_cursor_get_type    (void) G_GNUC_CONST;
+
 EBookCacheCursor *
                e_book_cache_cursor_new         (EBookCache *book_cache,
                                                 const gchar *sexp,
diff --git a/src/addressbook/libedata-book/e-book-meta-backend.c 
b/src/addressbook/libedata-book/e-book-meta-backend.c
index 79399d618..b93f8341b 100644
--- a/src/addressbook/libedata-book/e-book-meta-backend.c
+++ b/src/addressbook/libedata-book/e-book-meta-backend.c
@@ -1201,7 +1201,7 @@ ebmb_get_backend_property (EBookBackend *book_backend,
        }
 
        /* Chain up to parent's method. */
-       return E_BOOK_BACKEND_CLASS (e_book_meta_backend_parent_class)->get_backend_property (book_backend, 
prop_name);
+       return E_BOOK_BACKEND_CLASS (e_book_meta_backend_parent_class)->impl_get_backend_property 
(book_backend, prop_name);
 }
 
 static gboolean
@@ -2466,15 +2466,15 @@ e_book_meta_backend_class_init (EBookMetaBackendClass *klass)
        book_backend_sync_class->get_contact_list_uids_sync = ebmb_get_contact_list_uids_sync;
 
        book_backend_class = E_BOOK_BACKEND_CLASS (klass);
-       book_backend_class->get_backend_property = ebmb_get_backend_property;
-       book_backend_class->start_view = ebmb_start_view;
-       book_backend_class->stop_view = ebmb_stop_view;
-       book_backend_class->get_direct_book = ebmb_get_direct_book;
-       book_backend_class->configure_direct = ebmb_configure_direct;
-       book_backend_class->set_locale = ebmb_set_locale;
-       book_backend_class->dup_locale = ebmb_dup_locale;
-       book_backend_class->create_cursor = ebmb_create_cursor;
-       book_backend_class->delete_cursor = ebmb_delete_cursor;
+       book_backend_class->impl_get_backend_property = ebmb_get_backend_property;
+       book_backend_class->impl_start_view = ebmb_start_view;
+       book_backend_class->impl_stop_view = ebmb_stop_view;
+       book_backend_class->impl_get_direct_book = ebmb_get_direct_book;
+       book_backend_class->impl_configure_direct = ebmb_configure_direct;
+       book_backend_class->impl_set_locale = ebmb_set_locale;
+       book_backend_class->impl_dup_locale = ebmb_dup_locale;
+       book_backend_class->impl_create_cursor = ebmb_create_cursor;
+       book_backend_class->impl_delete_cursor = ebmb_delete_cursor;
 
        backend_class = E_BACKEND_CLASS (klass);
        backend_class->authenticate_sync = ebmb_authenticate_sync;
diff --git a/src/addressbook/libedata-book/e-book-sqlite.c b/src/addressbook/libedata-book/e-book-sqlite.c
index da9e74221..272e6bb0c 100644
--- a/src/addressbook/libedata-book/e-book-sqlite.c
+++ b/src/addressbook/libedata-book/e-book-sqlite.c
@@ -7923,7 +7923,7 @@ e_book_sqlite_get_locale (EBookSqlite *ebsql,
 }
 
 /**
- * e_book_sqlite_cursor_new:
+ * e_book_sqlite_cursor_new: (skip)
  * @ebsql: An #EBookSqlite
  * @sexp: search expression; use NULL or an empty string to get all stored contacts.
  * @sort_fields: (array length=n_sort_fields): An array of #EContactFields as sort keys in order of priority
@@ -8010,7 +8010,7 @@ e_book_sqlite_cursor_new (EBookSqlite *ebsql,
 }
 
 /**
- * e_book_sqlite_cursor_free:
+ * e_book_sqlite_cursor_free: (skip)
  * @ebsql: An #EBookSqlite
  * @cursor: The #EbSqlCursor to free
  *
@@ -8065,7 +8065,7 @@ collect_results_for_cursor_cb (gpointer ref,
 }
 
 /**
- * e_book_sqlite_cursor_step:
+ * e_book_sqlite_cursor_step: (skip)
  * @ebsql: An #EBookSqlite
  * @cursor: The #EbSqlCursor to use
  * @flags: The #EbSqlCursorStepFlags for this step
@@ -8299,7 +8299,7 @@ e_book_sqlite_cursor_step (EBookSqlite *ebsql,
 }
 
 /**
- * e_book_sqlite_cursor_set_target_alphabetic_index:
+ * e_book_sqlite_cursor_set_target_alphabetic_index: (skip)
  * @ebsql: An #EBookSqlite
  * @cursor: The #EbSqlCursor to modify
  * @idx: The alphabetic index
@@ -8356,7 +8356,7 @@ e_book_sqlite_cursor_set_target_alphabetic_index (EBookSqlite *ebsql,
 }
 
 /**
- * e_book_sqlite_cursor_set_sexp:
+ * e_book_sqlite_cursor_set_sexp: (skip)
  * @ebsql: An #EBookSqlite
  * @cursor: The #EbSqlCursor
  * @sexp: The new query expression for @cursor
@@ -8394,7 +8394,7 @@ e_book_sqlite_cursor_set_sexp (EBookSqlite *ebsql,
 }
 
 /**
- * e_book_sqlite_cursor_calculate:
+ * e_book_sqlite_cursor_calculate: (skip)
  * @ebsql: An #EBookSqlite
  * @cursor: The #EbSqlCursor
  * @total: (out) (allow-none): A return location to store the total result set for this cursor
@@ -8480,7 +8480,7 @@ e_book_sqlite_cursor_calculate (EBookSqlite *ebsql,
 }
 
 /**
- * e_book_sqlite_cursor_compare_contact:
+ * e_book_sqlite_cursor_compare_contact: (skip)
  * @ebsql: An #EBookSqlite
  * @cursor: The #EbSqlCursor
  * @contact: The #EContact to compare
diff --git a/tests/libedata-book/test-book-meta-backend.c b/tests/libedata-book/test-book-meta-backend.c
index 577f54bc9..b288bf75e 100644
--- a/tests/libedata-book/test-book-meta-backend.c
+++ b/tests/libedata-book/test-book-meta-backend.c
@@ -223,7 +223,7 @@ e_book_meta_backend_test_get_backend_property (EBookBackend *book_backend,
        }
 
        /* Chain up to parent's method. */
-       return E_BOOK_BACKEND_CLASS (e_book_meta_backend_test_parent_class)->get_backend_property 
(book_backend, prop_name);
+       return E_BOOK_BACKEND_CLASS (e_book_meta_backend_test_parent_class)->impl_get_backend_property 
(book_backend, prop_name);
 }
 
 static gboolean
@@ -527,7 +527,7 @@ e_book_meta_backend_test_class_init (EBookMetaBackendTestClass *klass)
        book_meta_backend_class->remove_contact_sync = e_book_meta_backend_test_remove_contact_sync;
 
        book_backend_class = E_BOOK_BACKEND_CLASS (klass);
-       book_backend_class->get_backend_property = e_book_meta_backend_test_get_backend_property;
+       book_backend_class->impl_get_backend_property = e_book_meta_backend_test_get_backend_property;
 
        object_class = G_OBJECT_CLASS (klass);
        object_class->constructed = e_book_meta_backend_test_constructed;
@@ -1565,8 +1565,8 @@ test_cursor (EBookMetaBackend *meta_backend)
 
        backend_class = E_BOOK_BACKEND_GET_CLASS (meta_backend);
        g_return_if_fail (backend_class != NULL);
-       g_return_if_fail (backend_class->create_cursor != NULL);
-       g_return_if_fail (backend_class->delete_cursor != NULL);
+       g_return_if_fail (backend_class->impl_create_cursor != NULL);
+       g_return_if_fail (backend_class->impl_delete_cursor != NULL);
 
        backend_sync_class = E_BOOK_BACKEND_SYNC_GET_CLASS (meta_backend);
        g_return_if_fail (backend_sync_class != NULL);
@@ -1575,7 +1575,7 @@ test_cursor (EBookMetaBackend *meta_backend)
        g_return_if_fail (backend_sync_class->remove_contacts_sync != NULL);
 
        /* Create the cursor */
-       cursor = backend_class->create_cursor (E_BOOK_BACKEND (meta_backend),
+       cursor = backend_class->impl_create_cursor (E_BOOK_BACKEND (meta_backend),
                sort_fields, sort_types, 1, &error);
        g_assert_no_error (error);
        g_assert_nonnull (cursor);
@@ -1631,7 +1631,7 @@ test_cursor (EBookMetaBackend *meta_backend)
        g_assert_cmpint (e_data_book_cursor_get_position (cursor), ==, 2);
 
        /* Free the cursor */
-       success = backend_class->delete_cursor (E_BOOK_BACKEND (meta_backend), cursor, &error);
+       success = backend_class->impl_delete_cursor (E_BOOK_BACKEND (meta_backend), cursor, &error);
        g_assert_no_error (error);
        g_assert (success);
 }



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/addressbook/libedata-book/e-book-backend.h b/src/addressbook/libedata-book/e-book-backend.h
index ac32eb523..aa3e5d3f9 100644
--- a/src/addressbook/libedata-book/e-book-backend.h
+++ b/src/addressbook/libedata-book/e-book-backend.h
@@ -76,27 +76,27 @@ struct _EBookBackend {
  * EBookBackendClass:
  * @use_serial_dispatch_queue: Whether a serial dispatch queue should
  *                             be used for this backend or not. The default is %TRUE.
  * @get_backend_property: Fetch a property value by name from the backend
  * @open: Open the backend
  * @refresh: Refresh the backend
  * @create_contacts: Add and store the passed vcards
  * @modify_contacts: Modify the existing contacts using the passed vcards
  * @remove_contacts: Remove the contacts specified by the passed UIDs
  * @get_contact: Fetch a contact by UID
  * @get_contact_list: Fetch a list of contacts based on a search expression
  * @get_contact_list_uids: Fetch a list of contact UIDs based on a search expression
  * @start_view: Start up the specified view
  * @stop_view: Stop the specified view
  * @notify_update: Notify changes which might have occured for a given contact
  * @get_direct_book: For addressbook backends which support Direct Read Access,
  *                   report some information on how to access the addressbook persistance directly
  * @configure_direct: For addressbook backends which support Direct Read Access, configure a
  *                    backend instantiated on the client side for Direct Read Access, using data
  *                    reported from the server via the @get_direct_book method.
  * @set_locale: Store & remember the passed locale setting
  * @dup_locale: Return the currently set locale setting (must be a string duplicate, for thread safety).
  * @create_cursor: Create an #EDataBookCursor
  * @delete_cursor: Delete an #EDataBookCursor previously created by this backend
  * @closed: A signal notifying that the backend was closed
  * @shutdown: A signal notifying that the backend is being shut down
  *
@@ -118,77 +118,78 @@ struct _EBookBackendClass {
         * dispatch queue, but helps avoid thread-safety issues. */
        gboolean use_serial_dispatch_queue;
 
-       gchar *         (*get_backend_property) (EBookBackend *backend,
+       gchar *         (*impl_get_backend_property)
+                                                (EBookBackend *backend,
                                                 const gchar *prop_name);
 
-       void            (*open)                 (EBookBackend *backend,
+       void            (*impl_open)            (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable);
-       void            (*refresh)              (EBookBackend *backend,
+       void            (*impl_refresh)         (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable);
-       void            (*create_contacts)      (EBookBackend *backend,
+       void            (*impl_create_contacts) (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable,
                                                 const gchar * const *vcards,
                                                 guint32 opflags); /* bit-or of EBookOperationFlags */
-       void            (*modify_contacts)      (EBookBackend *backend,
+       void            (*impl_modify_contacts) (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable,
                                                 const gchar * const *vcards,
                                                 guint32 opflags); /* bit-or of EBookOperationFlags */
-       void            (*remove_contacts)      (EBookBackend *backend,
+       void            (*impl_remove_contacts) (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable,
                                                 const gchar * const *uids,
                                                 guint32 opflags); /* bit-or of EBookOperationFlags */
-       void            (*get_contact)          (EBookBackend *backend,
+       void            (*impl_get_contact)     (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable,
                                                 const gchar *id);
-       void            (*get_contact_list)     (EBookBackend *backend,
+       void            (*impl_get_contact_list)(EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable,
                                                 const gchar *query);
-       void            (*get_contact_list_uids)
+       void            (*impl_get_contact_list_uids)
                                                (EBookBackend *backend,
                                                 EDataBook *book,
                                                 guint32 opid,
                                                 GCancellable *cancellable,
                                                 const gchar *query);
 
-       void            (*start_view)           (EBookBackend *backend,
+       void            (*impl_start_view)      (EBookBackend *backend,
                                                 EDataBookView *view);
-       void            (*stop_view)            (EBookBackend *backend,
+       void            (*impl_stop_view)       (EBookBackend *backend,
                                                 EDataBookView *view);
 
-       void            (*notify_update)        (EBookBackend *backend,
+       void            (*impl_notify_update)   (EBookBackend *backend,
                                                 const EContact *contact);
 
        EDataBookDirect *
-                       (*get_direct_book)      (EBookBackend *backend);
-       void            (*configure_direct)     (EBookBackend *backend,
+                       (*impl_get_direct_book) (EBookBackend *backend);
+       void            (*impl_configure_direct)(EBookBackend *backend,
                                                 const gchar *config);
 
-       gboolean        (*set_locale)           (EBookBackend *backend,
+       gboolean        (*impl_set_locale)      (EBookBackend *backend,
                                                 const gchar *locale,
                                                 GCancellable *cancellable,
                                                 GError **error);
-       gchar *         (*dup_locale)           (EBookBackend *backend);
+       gchar *         (*impl_dup_locale)      (EBookBackend *backend);
        EDataBookCursor *
-                       (*create_cursor)        (EBookBackend *backend,
+                       (*impl_create_cursor)   (EBookBackend *backend,
                                                 EContactField *sort_fields,
                                                 EBookCursorSortType *sort_types,
                                                 guint n_fields,
                                                 GError **error);
-       gboolean        (*delete_cursor)        (EBookBackend *backend,
+       gboolean        (*impl_delete_cursor)   (EBookBackend *backend,
                                                 EDataBookCursor *cursor,
                                                 GError **error);
 
@@ -76,27 +76,27 @@ struct _EBookBackend {
  * @use_serial_dispatch_queue: Whether a serial dispatch queue should
  *                             be used for this backend or not. The default is %TRUE.
- * @get_backend_property: Fetch a property value by name from the backend
- * @open: Open the backend
- * @refresh: Refresh the backend
- * @create_contacts: Add and store the passed vcards
- * @modify_contacts: Modify the existing contacts using the passed vcards
- * @remove_contacts: Remove the contacts specified by the passed UIDs
- * @get_contact: Fetch a contact by UID
- * @get_contact_list: Fetch a list of contacts based on a search expression
- * @get_contact_list_uids: Fetch a list of contact UIDs based on a search expression
- * @start_view: Start up the specified view
- * @stop_view: Stop the specified view
- * @notify_update: Notify changes which might have occured for a given contact
- * @get_direct_book: For addressbook backends which support Direct Read Access,
+ * @impl_get_backend_property: Fetch a property value by name from the backend
+ * @impl_open: Open the backend
+ * @impl_refresh: Refresh the backend
+ * @impl_create_contacts: Add and store the passed vcards
+ * @impl_modify_contacts: Modify the existing contacts using the passed vcards
+ * @impl_remove_contacts: Remove the contacts specified by the passed UIDs
+ * @impl_get_contact: Fetch a contact by UID
+ * @impl_get_contact_list: Fetch a list of contacts based on a search expression
+ * @impl_get_contact_list_uids: Fetch a list of contact UIDs based on a search expression
+ * @impl_start_view: Start up the specified view
+ * @impl_stop_view: Stop the specified view
+ * @impl_notify_update: Notify changes which might have occured for a given contact
+ * @impl_get_direct_book: For addressbook backends which support Direct Read Access,
  *                   report some information on how to access the addressbook persistance directly
@@ -76,27 +76,27 @@ struct _EBookBackend {
  *                   report some information on how to access the addressbook persistance directly
- * @configure_direct: For addressbook backends which support Direct Read Access, configure a
+ * @impl_configure_direct: For addressbook backends which support Direct Read Access, configure a
  *                    backend instantiated on the client side for Direct Read Access, using data
  *                    reported from the server via the @get_direct_book method.
@@ -76,27 +76,27 @@ struct _EBookBackend {
  *                    backend instantiated on the client side for Direct Read Access, using data
  *                    reported from the server via the @get_direct_book method.
- * @set_locale: Store & remember the passed locale setting
- * @dup_locale: Return the currently set locale setting (must be a string duplicate, for thread safety).
- * @create_cursor: Create an #EDataBookCursor
- * @delete_cursor: Delete an #EDataBookCursor previously created by this backend
+ * @impl_set_locale: Store & remember the passed locale setting
+ * @impl_dup_locale: Return the currently set locale setting (must be a string duplicate, for thread safety).
+ * @impl_create_cursor: Create an #EDataBookCursor
+ * @impl_delete_cursor: Delete an #EDataBookCursor previously created by this backend
  * @closed: A signal notifying that the backend was closed
  * @shutdown: A signal notifying that the backend is being shut down